pub enum RequestMetadataError {
NotFound,
MethodNotAllowed,
UnsupportedMediaType,
NotAcceptable,
}Expand description
A failure while validating inbound HTTP request metadata.
Variants
NotFound
The request URI does not exactly identify the selected standard route.
MethodNotAllowed
A known standard route was requested with a method other than POST.
UnsupportedMediaType
The request body does not use UTF-8 application/json or identity coding.
NotAcceptable
The request’s Accept metadata excludes application/json.
Implementations